#
# WiKicker
#
#  DRCommand.t
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DRCommand.t,v 1.2 2004/12/13 12:53:46 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 132 }

use WiKicker::DikiCGI::RequestCommand;

{
  my $command = WiKicker::DikiCGI::RequestCommand->new(path_info => '');
  ok($command->type, 'd');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command = WiKicker::DikiCGI::RequestCommand->new(path_info => '/');
  ok($command->type, 'd');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command = WiKicker::DikiCGI::RequestCommand->new(path_info => '/d');
  ok($command->type, 'd');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command = WiKicker::DikiCGI::RequestCommand->new(path_info => '/d.html');
  ok($command->type, 'd');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command = WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/');
  ok($command->type, 'd');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/rss.rdf');
  ok($command->type, 'd');
  ok($command->range_type, 'recent');
  ok($command->name, '');
  ok($command->format, 'rss');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-01.html');
  ok($command->type, 'd');
  ok($command->range_type, 'day');
  ok($command->range, '2004-01-01');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-01:2004-01-05.html');
  ok($command->type, 'd');
  ok($command->range_type, 'day-to-day');
  ok($command->range, '2004-01-01:2004-01-05');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-05:2004-01-01.html');
  ok($command->type, 'd');
  ok($command->range_type, 'day-to-day');
  ok($command->range, '2004-01-05:2004-01-01');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-05:5-.html');
  ok($command->type, 'd');
  ok($command->range_type, 'day-to');
  ok($command->range, '2004-01-05:5-');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-05:-5.html');
  ok($command->type, 'd');
  ok($command->range_type, 'day-from');
  ok($command->range, '2004-01-05:-5');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-a.html');
  ok($command->type, 'd');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2004-01-a');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-b.html');
  ok($command->type, 'd');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2004-01-b');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-c.html');
  ok($command->type, 'd');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2004-01-c');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/2004-01-05-1.html');
  ok($command->type, 'd');
  ok($command->range_type, 'article');
  ok($command->range ,'2004-01-05-1');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/d/01-01.html');
  ok($command->type, 'd');
  ok($command->range_type, 'month-day');
  ok($command->range ,'01-01');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/dn/keyword.html');
  ok($command->type, 'd');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/drn/2004-01-a/keyword.html');
  ok($command->type, 'd');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2004-01-a');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/t');
  ok($command->type, 't');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}


{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/t/');
  ok($command->type, 't');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/t.html');
  ok($command->type, 't');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/t/2003-01-a.html');
  ok($command->type, 't');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2003-01-a');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/tn/keyword.html');
  ok($command->type, 't');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/trn/2003-01-a/keyword.html');
  ok($command->type, 't');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2003-01-a');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/k');
  ok($command->type, 'k');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/k/');
  ok($command->type, 'k');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/k.html');
  ok($command->type, 'k');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/k/keyword.html');
  ok($command->type, 'k');
  ok($command->range_type, 'no');
  ok($command->range, 'no');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/kr/2003-01-a.html');
  ok($command->type, 'k');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2003-01-a');
  ok($command->name, '');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/dk/keyword.html');
  ok($command->type, 'dk');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/dkr/2003-01-a/keyword.html');
  ok($command->type, 'dk');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2003-01-a');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/tk/keyword.html');
  ok($command->type, 'tk');
  ok($command->range_type, 'recent');
  ok($command->range, 'recent');
  ok($command->name, 'keyword');
}

{
  my $command =
    WiKicker::DikiCGI::RequestCommand->new(path_info => '/tkr/2003-01-a/keyword.html');
  ok($command->type, 'tk');
  ok($command->range_type, 'ten-day');
  ok($command->range, '2003-01-a');
  ok($command->name, 'keyword');
}
