#
# WiKicker
#
#  DbFile.t
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DbFile.t,v 1.5 2004/06/11 14:51:13 naney Exp $
#
#

use strict;
use Test;
use File::Path;

BEGIN { plan tests => 17 }

use WiKicker::DB::File;
use WiKicker::TrackBack::EntryMap;
use WiKicker::TrackBack::Entry;
use Storable;

rmtree(['/tmp/WiKicker-test-db'], 0);

# last_modified_file_name
{
  my $db = WiKicker::DB::File->new('/tmp/WiKicker-test-db');
  ok($db->last_modified_file_name eq '/tmp/WiKicker-test-db/last-modified.txt');
  ok(! -e $db->last_modified_file_name);
  ok($db->db_last_modified_time == 0);
}

# basic
{
  my $db = WiKicker::DB::File->new('/tmp/WiKicker-test-db');

  $db->shared_lock_pages;
  ok(! $db->exists_live_page('key'));
  ok(! $db->page('key'));
  $db->unlock_pages;
  ok(! -e $db->last_modified_file_name);
  ok($db->db_last_modified_time == 0);

  $db->exclusive_lock_pages;
  $db->page('key', 'value');
  ok($db->page('key') eq 'value');
  $db->unlock_pages;
  ok(-e $db->last_modified_file_name);
  my $now = time;
  my $db_last_modified_time = $db->db_last_modified_time;
  ok($db_last_modified_time <= $now && $now - 5 <= $db_last_modified_time);
}

# delete
{
  my $db = WiKicker::DB::File->new('/tmp/WiKicker-test-db');
  ok(!$db->exists_live_page('deletetest'));
  $db->exclusive_lock_pages;
  $db->page('deletetest', 'value');
  ok($db->page('deletetest') eq 'value');
  ok($db->exists_live_page('deletetest'));
  $db->delete_page('deletetest');
  ok(!$db->exists_live_page('deletetest'));
  $db->unlock_pages;
}


# information
{
  my $db = WiKicker::DB::File->new('/tmp/WiKicker-test-db');

  $db->exclusive_lock_pages;
  $db->information('key', 'author', 'naney');
  $db->shared_lock_pages;
  ok($db->information('key', 'author') eq 'naney');
}

# cache
{
  my $db = WiKicker::DB::File->new('/tmp/WiKicker-test-db');
  $db->cache('link', 'key', 'a b');
  ok($db->cache('link', 'key') eq 'a b');
}

# cache (TrackBack)
{
  my $db = WiKicker::DB::File->new('/tmp/WiKicker-test-db');

  my $entry_map = WiKicker::TrackBack::EntryMap->new;
  my $entry = WiKicker::TrackBack::Entry->new;
  $entry->url('http://www.naney.org/');
  $entry_map->set($entry);

  $db->cache('trackback', 'key', Storable::freeze($entry_map));

  my $entry_map2 = Storable::thaw($db->cache('trackback', 'key'));
  my $entry2 = $entry_map2->get('http://www.naney.org/');
  ok($entry2->url eq 'http://www.naney.org/');
}

#page log
# {
#   my $db = WiKicker::DB::File->new('/tmp/WiKicker-test-db');
#   $db->page_log('common', 'key', "log1\n");
#   ok($db->page_log('common', 'key') eq "log1\n");
#   $db->append_page_log('common', 'key', "log2\n");
#   ok($db->page_log('common', 'key') eq "log1\nlog2\n");
# }
