#
# WiKicker
#
#  DocumentParser.t
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DocumentParser.t,v 1.3 2003/10/26 23:07:34 naney Exp $
#
#

use strict;
use Test;

BEGIN { plan tests => 149 }

use WiKicker::WikiPage::DocumentParser;
use WiKicker::WRI::Factory;

my $factory = WiKicker::WRI::Factory->new;

# empty
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse('');
  ok($document_node->size == 0);
  ok($document_node->to_string eq '');
}

# only one paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse('a');
  ok($document_node->size == 1);
  ok($document_node->to_string eq 'a');
}

# only one japanese paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse('あいうえおかきくけこさしすせそたちつてとなにぬねの');
  ok($document_node->size == 1);
  ok($document_node->to_string eq 'あいうえおかきくけこさしすせそたちつてとなにぬねの');
  my @nodes = $document_node->nodes;
  ok(ref $nodes[0] eq 'WiKicker::WikiPage::ParagraphNode');
}


# two paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("one\n\ntwo");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "one\n");
  ok($nodes[1]->to_string eq "\n");
  ok($nodes[2]->to_string eq "two");
}

# paragraph, tow empty line, paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("one\n\n\ntwo");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "one\n");
  ok($nodes[1]->to_string eq "\n\n");
  ok($nodes[2]->to_string eq "two");
}


# h1
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("*h1\np\np");
  ok($document_node->size == 2);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "*h1\n");
  ok($nodes[0]->level == 1);
  ok($nodes[1]->to_string eq "p\np");
}

# h2
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("*h1\np1\n**h2\np2\n");
  ok($document_node->size == 4);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "*h1\n");
  ok($nodes[1]->to_string eq "p1\n");
  ok($nodes[2]->to_string eq "**h2\n");
  ok($nodes[3]->to_string eq "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n-kkk\np2");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "-kkk\n");
  ok($nodes[2]->to_string eq "p2");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n#kkk\np2");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "#kkk\n");
  ok($nodes[2]->to_string eq "p2");
}


# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
--kkk
p2
EOS
  my $document_node = $parser->parse($text);
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "--kkk\n");
  ok($nodes[2]->to_string eq "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
##kkk
p2
EOS
  my $document_node = $parser->parse($text);
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "##kkk\n");
  ok($nodes[2]->to_string eq "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
---kkk
p2
EOS
  my $document_node = $parser->parse($text);
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "---kkk\n");
  ok($nodes[2]->to_string eq "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
###kkk
p2
EOS
  my $document_node = $parser->parse($text);
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "###kkk\n");
  ok($nodes[2]->to_string eq "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
-a
--b
p2
EOS
  my $document_node = $parser->parse($text);
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "-a\n--b\n");
  ok($nodes[2]->to_string eq "p2\n");
}

# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
#a
##b
p2
EOS
  my $document_node = $parser->parse($text);
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "#a\n##b\n");
  ok($nodes[2]->to_string eq "p2\n");
}


# list
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $text = '--- book';
  my $document_node = $parser->parse($text);
  ok($document_node->to_string eq '--- book');
}

# hr
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
my $text = <<EOS;
p1
----
p2
EOS
  my $document_node = $parser->parse($text);
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "----\n");
  ok($nodes[2]->to_string eq "p2\n");
}


# paragraph, pre, paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n k\n k\n k\np2");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq " k\n k\n k\n");
  ok($nodes[2]->to_string eq "p2");
}

# paragraph,pre,empty,paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n k\n\np2");
  ok($document_node->size == 4);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq " k\n");
  ok($nodes[2]->to_string eq "\n");
  ok($nodes[3]->to_string eq "p2");
}

# paragraph,pre,empty,pre,paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n pre1\n\n\n pre2\np2");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq " pre1\n\n\n pre2\n");
  ok($nodes[2]->to_string eq "p2");
}

# paragraph,empty,pre,empty,pre,empty,paragraph
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n\n pre1\n\n\n pre2\n\np2");
  ok($document_node->size == 5);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "\n");
  ok($nodes[2]->to_string eq " pre1\n\n\n pre2\n");
  ok($nodes[3]->to_string eq "\n");
  ok($nodes[4]->to_string eq "p2");
}

# pre,empty
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse(" pre1\n\n");
  ok($document_node->size == 2);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq " pre1\n");
  ok($nodes[1]->to_string eq "\n");
}

# empty,pre
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("\n pre1");
  ok($document_node->size == 2);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "\n");
  ok($nodes[1]->to_string eq " pre1");
}

# quote
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("p1\n> k\n> k\n> k\np2");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq "> k\n> k\n> k\n");
  ok($nodes[2]->to_string eq "p2");
}

# dl
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse(<<EOS);
p1
:dt:dd
p2
EOS
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "p1\n");
  ok($nodes[1]->to_string eq ":dt:dd\n");
  ok($nodes[2]->to_string eq "p2\n");
}

# _trim
{
  my ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim('a');
  ok($left eq '');
  ok($body eq 'a');
  ok($right eq '');

  ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim(" abc");
  ok($left eq ' ');
  ok($body eq 'abc');
  ok($right eq '');

  ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim("abc ");
  ok($left eq '');
  ok($body eq 'abc');
  ok($right eq ' ');

  ($left, $body, $right) = WiKicker::WikiPage::DocumentParser::_trim(" abc ");
  ok($left eq ' ');
  ok($body eq 'abc');
  ok($right eq ' ');
}

# table |
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n|dog\n|cat\nb");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "a\n");
  ok($nodes[1]->to_string eq "|dog\n|cat\n");
  ok($nodes[2]->to_string eq "b");
}

# table ,
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n,dog\n,cat\nb");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "a\n");
  ok($nodes[1]->to_string eq ",dog\n,cat\n");
  ok($nodes[2]->to_string eq "b");
}

# table , (column with space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n,dog cat\nb");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "a\n");
  ok($nodes[1]->to_string eq ",dog cat\n");
  ok($nodes[2]->to_string eq "b");
}

# table , (left space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n, dog\nb");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "a\n");
  ok($nodes[1]->to_string eq ", dog\n");
  ok($nodes[2]->to_string eq "b");
}

# table , (right space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n,dog \nb");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "a\n");
  ok($nodes[1]->to_string eq ",dog \n");
  ok($nodes[2]->to_string eq "b");
}

# table , (left and right space)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n, dog \nb");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "a\n");
  ok($nodes[1]->to_string eq ", dog \n");
  ok($nodes[2]->to_string eq "b");
}

# table | (empty cell)
{
  my $parser = WiKicker::WikiPage::DocumentParser->new(wri_factory => $factory);
  my $document_node = $parser->parse("a\n|a||\nb");
  ok($document_node->size == 3);
  my @nodes = $document_node->nodes;
  ok($nodes[0]->to_string eq "a\n");
  ok($nodes[1]->to_string eq "|a||\n");
  ok($nodes[2]->to_string eq "b");
}

{
  my @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a', '|');
  ok(@result == 1);
  ok($result[0] eq 'a');

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a|', '|');
  ok(@result == 2);
  ok($result[0] eq 'a');
  ok($result[1] eq '');

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a||', '|');
  ok(@result == 3);
  ok($result[0] eq 'a');
  ok($result[1] eq '');
  ok($result[2] eq '');

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('a|b|c', '|');
  ok(@result == 3);
  ok($result[0] eq 'a');
  ok($result[1] eq 'b');
  ok($result[2] eq 'c');

  @result = WiKicker::WikiPage::DocumentParser::_split_to_cell('', '|');
  ok(@result == 1);
  ok($result[0] eq '');
}
